@@ -1,7 +1,12 @@
 from .node import Node, NodeException
 from .resolver import Resolver, ResolverException, UpdateOperation, FilterConnector
 from .batch import Batch
-from .unset import Unset, ComputedPropertyException, AppendixPropertyException, is_unset
+from .unset import (
+    UnsetType,
+    ComputedPropertyException,
+    AppendixPropertyException,
+    UNSET,
+)
 from .validators import from_str, enum_from_str
 from .enums import PropertyCardinality
 from .base_patch import BasePatch
