@@ -1,6 +1,6 @@
 import typing as T
 from pydantic import BaseModel
-from edgedb_orm import is_unset
+from edgedb_orm import UNSET
 
 
 class BasePatch(BaseModel):
@@ -14,5 +14,5 @@ class BasePatch(BaseModel):
         return {
             field
             for field in self.__fields__
-            if field not in exclude and not is_unset(getattr(self, field))
+            if field not in exclude and getattr(self, field) is not UNSET
         }
